Cisco.ASA
=========

====== ========================================
Vendor `Cisco Systems <http://www.cisco.com/>`_
OS     ASA
====== ========================================

Cisco.ASA profile supports Adaptive Security Appliance (ASA) family of the firewalls

Tested Equipment
----------------
.. supported:: Cisco.ASA

